@@ -8,7 +8,7 @@ import geopandas as gpd
 from tqdm import tqdm
 import PySimpleGUI as sg
 from shapely.geometry import Polygon
-from shapely.ops import cascaded_union
+from shapely.ops import cascaded_union, unary_union
 pd.options.mode.chained_assignment = None
 
 class check_topology:
